using Configuration.Middlewares;
using Configuration.Models;
using Configuration.Services;
using Microsoft.Extensions.Configuration;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.
builder.Services.AddControllersWithViews();
builder.Services.AddSingleton<TotalUsers>();

builder.Services.Configure<MyWebApi>(builder.Configuration.GetSection("APIEndpoints"));
builder.Services.Configure<Connections>(builder.Configuration.GetSection("ConnectionStrings"));

var app = builder.Build();

// Configure the HTTP request pipeline.
if (!app.Environment.IsDevelopment())
{
	app.UseExceptionHandler("/Home/Error");
	// The default HSTS value is 30 days.
	app.UseHsts();
}

app.UseHttpsRedirection();
app.UseStaticFiles();

app.UseMiddleware<ResponseEditingMiddleware>();
app.UseMiddleware<RequestEditingMiddleware>();
app.UseMiddleware<ShortCircuitMiddleware>();
app.UseMiddleware<ContentMiddleware>();

/*if (Convert.ToBoolean(app.Configuration["Middleware:EnableResponseEditingMiddleware"]))
{
	app.UseMiddleware<ResponseEditingMiddleware>();
}
if (Convert.ToBoolean(app.Configuration["Middleware:EnableRequestEditingMiddleware"]))
{
	app.UseMiddleware<RequestEditingMiddleware>();
}
if (Convert.ToBoolean(app.Configuration["Middleware:EnableShortCircuitMiddleware"]))
{
	app.UseMiddleware<ShortCircuitMiddleware>();
}
if (Convert.ToBoolean(app.Configuration["Middleware:EnableContentMiddleware"]))
{
	app.UseMiddleware<ContentMiddleware>();
}*/

app.UseRouting();

app.UseAuthorization();

app.MapControllerRoute(
	name: "default",
	pattern: "{controller=Home}/{action=Index}/{id?}");

app.Run();
